Package: OmaDB
Title: R wrapper for the OMA REST API
Version: 2.28.0
Author: Klara Kaleb 
Maintainer: Klara Kaleb <klara.kaleb18@ic.ac.uk>, Adrian Altenhoff <adrian.altenhoff@inf.ethz.ch>
Description: A package for the orthology prediction data download from OMA database.
Depends: R (>= 3.5), httr (>= 1.2.1), plyr(>= 1.8.4)
Imports: utils, ape, Biostrings, GenomicRanges, IRanges, methods,
        topGO, jsonlite
URL: https://github.com/DessimozLab/OmaDB
BugReports: https://github.com/DessimozLab/OmaDB/issues
Encoding: UTF-8
License: GPL-3
LazyData: true
Suggests: knitr, rmarkdown, testthat
VignetteBuilder: knitr
biocViews: Software, ComparativeGenomics, FunctionalGenomics, Genetics,
        Annotation, GO, FunctionalPrediction
RoxygenNote: 7.1.1
git_url: https://git.bioconductor.org/packages/OmaDB
git_branch: RELEASE_3_23
git_last_commit: de716ca
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-30
NeedsCompilation: no
Packaged: 2026-04-30 21:15:50 UTC; biocbuild
Built: R 4.6.0; ; 2026-05-01 03:08:37 UTC; unix
