# Generated by roxygen2: do not edit by hand

S3method("$",omadb_obj)
export(annotateSequence)
export(formatTopGO)
export(getAnnotation)
export(getAttribute)
export(getData)
export(getGenome)
export(getGenomeAlignment)
export(getGenomePairs)
export(getHOG)
export(getLocus)
export(getOMAGroup)
export(getObjectAttributes)
export(getProtein)
export(getTaxonomy)
export(getTopGO)
export(getTree)
export(getVersion)
export(getXref)
export(mapSequence)
export(resolveURL)
export(searchProtein)
export(setAPI)
import(ape)
import(httr)
import(plyr)
import(topGO)
importFrom(Biostrings,AAString)
importFrom(Biostrings,DNAString)
importFrom(GenomicRanges,GRanges)
importFrom(GenomicRanges,makeGRangesFromDataFrame)
importFrom(IRanges,IRanges)
importFrom(ape,read.tree)
importFrom(methods,new)
importFrom(topGO,annFUN.gene2GO)
importFrom(utils,URLencode)
importFrom(utils,packageVersion)
