% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/objects_docs.R
\docType{data}
\name{pairs}
\alias{pairs}
\title{An example genome alignment object.}
\format{A dataframe object with 12 variables for each member of the pair, as well some 3 additional variables:
\describe{
  \item{entry_nr}{entry number of the ortholog}
  \item{omaid}{oma identifier of the ortholog}
  \item{canonicalid}{canonicalid of the ortholog}
  \item{sequence_md5}{sequence_md5 of the ortholog}
  \item{oma_group}{oma_group of the ortholog}
  \item{oma_hog_id}{hog id of the ortholog}
  \item{chromosome}{chromosomal location of the ortholog}
  \item{locus.start}{start locus of the ortholog}
  \item{locus.end}{end locus of the ortholog}
  \item{locus.strand}{locus strand of the ortholog}
  \item{is_main_isoform}{true/false}
  \item{rel_type}{relationship type of the ortholog to the gene}
  \item{distance}{ortholog distance}
  \item{score}{ortholog score}
  ...
}}
\source{
\url{https://omabrowser.org/api/pairs/YEAST/ASHGO/}
}
\usage{
pairs
}
\description{
A dataframe containing information for the whole genome aligment of YEAST and ASHGO.
}
\keyword{datasets}
